*/ ACTIVATE IMPUTED DATA FOR ANALYSIS */.

get file = '/users/craig/desktop/spss imputation/imputed data.sav'.
dataset name imputeddata window = front.

*/ DISCARD FIRST IMPUTED DATA SET */.

select if imputation_ gt 1.
exe.  

*/ COMPUTE SCALE SCORES WITHIN EACH DATA SET */

compute bodydis = sum(bds1 to bds7).
compute eatrisk = sum(edr1 to edr6).
exe.  

*/ CENTER BODY DISSATISFACTION WITHIN EACH DATA SET */

aggregate
 /outfile = * mode = addvariables
 /presorted
 /break = imputation_
 /bodydismean = mean(bodydis). 

compute bodydiscent = bodydis - bodydismean.
exe.  

*/ SAVE UPDATED DATA */

save outfile = '/users/craig/desktop/spss imputation/imputed data.sav'.

*/ SPLIT THE FILE BY VARIABLE IMPUTATION_ TO ANALYZE DATA SETS SEPARATELY */

dataset activate imputeddata.

sort cases by imputation_.
split file layered by imputation_.

*/ REGRESSION ANALYSIS */

regression
 /statistics coeff outs r anova
 /dependent eatrisk
 /method = enter bodydiscent abuse.

*/ REGRESSION ANALYSIS SAVING R-SQUARE  VALUES TO A DATA SET */

oms select tables
 /destination format = sav outfile = '/users/craig/desktop/spss imputation/rsquares.sav'
 /if commands = ['Regression'] subtypes = ['Model Summary']
 /tag = "rsquare".

regression
 /statistics coeff outs r anova
 /dependent eatrisk
 /method = enter bodydiscent abuse.

omsend tag = ["rsquare"].
omsinfo.

*/ REGRESSION ANALYSIS SAVING BETA WEIGHTS TO A DATA SET */

oms select tables
 /destination format = sav outfile = '/users/craig/desktop/spss imputation/betas.sav'
 /if commands = ['Regression'] subtypes = ['Coefficients']
 /tag = "beta".

regression
 /statistics coeff outs r anova
 /dependent eatrisk
 /method = enter bodydiscent abuse.

omsend tag = ["beta"].
omsinfo.

*/ ACTIVATE RSQUARE DATA FILE AND COMPUTE AVERAGE R-SQUARE */.

get file = '/users/craig/desktop/spss imputation/rsquares.sav'.
dataset name rsquares window = front.

select if var1 ne ' '.
title 'AVERAGE R-SQUARE VALUE FROM REGRESSION ANALYSIS'.
descriptives var = r rsquare adjustedrsquare.

dataset close rsquares.

*/ ACTIVATE BETA WEIGHT DATA FILE AND COMPUTE AVERAGE BETA WEIGHTS */.

get file = '/users/craig/desktop/spss imputation/betas.sav'.
dataset name betas window = front.

title 'AVERAGE BETA WEIGHTS FROM REGRESSION ANALYSIS'.
means beta by var3
 /cells count mean stddev min max.

dataset close betas.

*/ RELIABILITY ANALYSIS */

oms select tables
 /destination format = sav outfile = '/users/craig/desktop/spss imputation/bdsreliability.sav'
 /if commands = ['Reliability'] subtypes = ['Reliability Statistics']
 /tag = "bdsreliability".

reliability vars = bds1 to bds7
 /scale(bds) = bds1 to bds7. 

omsend tag = ["bdsreliability"].
omsinfo.

oms select tables
 /destination format = sav outfile = '/users/craig/desktop/spss imputation/edrreliability.sav'
 /if commands = ['Reliability'] subtypes = ['Reliability Statistics']
 /tag = "edrreliability".

reliability vars = edr1 to edr6
 /scale(edr) = edr1 to edr6. 

omsend tag = ["edrreliability"].
omsinfo.

*/ ACTIVATE RELIABILITY DATA FILES AND COMPUTE AVERAGE COEFFICIENT ALPHA */.

get file = '/users/craig/desktop/spss imputation/bdsreliability.sav'.
dataset name bdsreliability window = front.
select if var1 ne ' '.

title 'AVERAGE COEFFICIENT ALPHA VALUE FOR BDS SCALE'.
descriptives var = cronbachsalpha.

get file = '/users/craig/desktop/spss imputation/edrreliability.sav'.
dataset name edrreliability window = front.
select if var1 ne ' '.

title 'AVERAGE COEFFICIENT ALPHA VALUE FOR EDR SCALE'.
descriptives var = cronbachsalpha.



