*/////////////////////////////////////////////////////////////////*
*/////                SPSS MCMC DIAGNOSTIC MACRO                     /////*
*///// This program calculates the potential scale reduction    /////*
*///// factor and produces trace plots.  Before running the      /////*
*///// program, perform an exploratory MCMC chain with       /////*
*///// 2 imputations and 1000 iterations.  Save the iteration   /////*
*///// history to a file named parameters.sav.  The diagnostic /////*
*///// macro requires the file path of the folder containing     /////*
*///// the parameter.sav file and the variables in that file.       /////*
*/////////////////////////////////////////////////////////////////*

define diagnosticmacro ()

*/ !FOLDER = FILE PATH TO THE FOLDER CONTAINING THE PARAMETERS.SAV FILE */.
*/ !VARS = VARIABLES IN THE PARAMETERS.SAV FILE */.

!let !folder =  '/users/craig/desktop/computer files/spss/'
!let !vars = 'bmi bds1 bds2 bds4 bds7 edr2 edr3 edr5'

*/////////////////////////////////////////////////////////////////*
*/////                DO NOT ALTER THE CODE BELOW                    /////*
*/////////////////////////////////////////////////////////////////*

get file = !quote(!concat(!folder,'parameters.sav')).
dataset name parameters window = front.
sort cases by summarystatistic_ imputations_ iteration_.
select if (iteration_ gt 0).

*/ DIVIDE MCMC CHAIN INTO 100 CYCLE INTERVALS */

do repeat 
  impgrp = imp100 imp200 imp300 imp400 imp500 imp600 imp700 imp800 imp900 imp1000
 /group = 100 200 300 400 500 600 700 800 900 1000.

if (imputations_ = 1 and iteration_ le group) impgrp = 1.
if (imputations_ = 2 and iteration_ le group) impgrp = 2.

end repeat.
exe.  

*/ EXTRACT WITHIN AND BETWEEN CHAIN VARIANCE FROM MEANS PROCEDURE */

!do !i = 0 !to 1

dataset activate parameters.

oms select tables
!if (!i = 0) !then
 /destination format = sav outfile = !quote(!concat(!folder,'means.sav'))
!ifend
!if (!i = 1) !then
 /destination format = sav outfile = !quote(!concat(!folder,'stddevs.sav'))
!ifend
 /if commands = ['Means'] subtypes = ['ANOVA']
 /tag = "psr".

temporary.   
select if (summarystatistic_ = !i).
means tables = !vars by  imp100 imp200 imp300 imp400 imp500 imp600 imp700 imp800 imp900 imp1000
 /statistics anova.

omsend tag = ["psr"].
omsinfo.

*/ COMPUTE POTENTIAL SCALE REDUCTION FACTOR */

!if (!i = 0) !then
get file = !quote(!concat(!folder,'means.sav')).
dataset name means window = front.
!ifend

!if (!i = 1) !then
get file = !quote(!concat(!folder,'stddevs.sav')).
dataset name stddevs window = front.
!ifend

select if (var2 = 'Between Groups').
rename variables (meansquare = between).
compute within = between * (1 / F).
string variable (a12).
string convergence (a36).
string parameter (a6).
string int (a4).
compute asterisk = index(var1, '*'). 
compute variable = substr(var1, 1, asterisk-1).
compute imp = index(var1, 'imp').
compute int = substr(var1, imp+3).
recode int (convert) into interval.
compute numerator = (1 - 1/interval)*within + (1/interval)*between.
compute potential_scale_reduction = sqrt( numerator / within).
compute convergence = 'converged (psr < 1.05)'.
if (potential_scale_reduction gt 1.05) convergence = 'increase iterations (psr > 1.05)'.
!if (!i = 0) !then
compute parameter = 'mean'.
!ifend
!if (!i = 1) !then
compute parameter = 'stddev'.
!ifend
exe.  

delete variables command_ subtype_ label_ var1 var2 var3 sumofsquares df f sig asterisk within between imp int numerator. 
exe.  

!doend

output close *.

*/ PRINT TABLE OF PSR VALUES BY BETWEEN-IMPUTATION INTERVAL */

dataset activate means.
add files / file = *
 /file = stddevs.
exe. 

title 'PSR STATISTIC FOR VARIABLE MEANS AND STANDARD DEVIATIONS'.
list cases / var = parameter variable interval  potential_scale_reduction convergence.

dataset close stddevs.

*/ GRAPH MAXIMUM PSR VALUE BY BETWEEN-IMPUTATION INTERVAL */

dataset activate means.
dataset declare psrmax.
aggregate
  /outfile ='psrmax'
  /break = interval
  /psr_max = max(potential_scale_reduction).

dataset activate psrmax.
compute converged = 1.05.
exe. 

graph
  /line(multiple) = value(psr_max converged) by interval
  /title = 'Maximum PSR Value by Between-Imputation Interval'.

dataset close psrmax.
dataset close means.

*/ TRACE PLOTS */

dataset activate parameters.

!do !i !in (!vars)

!let !title = !concat('TRACE PLOT OF MEANS FOR VARIABLE ', !UPCASE(!i))

temp.
select if (summarystatistic_ = 0 and iteration_ le 1000 and imputations_ = 1).
graph
  /line(simple) = value(!i) by iteration_
  /title = !quote(!title).

!let !title = !concat('TRACE PLOT OF STANDARD DEVIATIONS FOR VARIABLE ', !UPCASE(!i))

temp.
select if (summarystatistic_ = 1 and iteration_ le 1000 and imputations_ = 1).
graph
  /line(simple) = value(!i) by iteration_
  /title = !quote(!title).

!doend

!enddefine.
diagnosticmacro.
exe. 

